==============
Marshmallow-BR
==============

This library provides Marshmallow fields and validators for Brazilian documents:

* CNH
* CNPJ
* CPF
* Brazilian birth, marriage and death certificates
* Brazilian phone number
